%Contents of the three-way chemometrics toolbox,
%Foodtechnology, Copenhagen, Rel. 10-06-95
%
% PROGRAMS FOR SOLVING MODELS --------------------------------------
%
%  These programs are used for solving tri-linear models.
%  Use the 'help xxxxx' command on each program to get more help
%  on each of the models.
%
%  ftupca01   Solutions provided by simple unfolding,
%             also known as unfold-PCA or TUCKER1-solutions.
%             MUST be available for all other programs.
%
%  fttuck01   Solutions to the TUCKER3 model,
%             unconstrained.
%
%  fttuck02   Has been removed!
%
%  fttuck03   Solutions to the TUCKER3 model,
%             normalized A, B and C.
%
%  fttuck04   Solutions to the TUCKER3 model,
%             non-iterative, EVP-solutions.
%
%  ftpara01   Solutions to the PARAFAC/CANDECOMP model,
%             unconstrained and accelerated.
%
%  ftpara02   Solutions to the PARAFAC/CANDECOMP model,
%             unconstrained but not accelerated.
%
%  ftpara03   Solutions to the PARAFAC/CANDECOMP model,
%             constrained B and C giving score-like A's.
%
%  fttpls01   Derives the PLS-factors from X- and Y-data.
%
%  ftgram01   Uses Generalized Rank Annihilation Method
%             to calculate the concentration of any specie
%             in an array, provided that an array with the
%             specie in known concentration is available.
%
% PROGRAMS FOR CALCULATING PREDICTIONS -----------------------------
%
%  These programs rely on the programs above. Predictions
%  based on multivariate three-way structures can only
%  be performed if calibration data is available. If you have 
%  some known features (Y-data) of X-data, these programs can 
%  provide predictions of features of NEW X-data.
%
%  ftupcap1   Uses unfold-PCA to establish the parameters
%             for prediction of the calibrated features of
%             new samples. Not to be recommended!
%
%  fttuckp1   Performs calibration on sampled X-data with
%             its belonging Y-data by the TUCKER3-model.
%             After calibration, new X-data can have
%             its Y-values predicted.   
%
%  ftparap1   The PARAFAC/CANDECOMP model is used to provide 
%             scores and loadings of the calibration set so
%             that future samples can have its features predicted.
%
%  fttplsp1   Uses the PLS-regression philosophy to perform
%             predictions. This will propably provide the best
%             predictions due to the inherent optimization of 
%             the describence of the variation in Y.
%             Currently being revised!
%
% SPECIALITIES -----------------------------------------------------
%
%  ftopti01   Facilitates speed improvements by calculating
%             solutions to reduced problems and using 
%             interpolations between these solutions 
%             as start guesses to the total problem.
%
% NECESSARY UTILITIES ----------------------------------------------
%
%  fnipals1   Calculates the eigenvectors of any matrix using
%             the power method. Often faster than SVD() and EIG() 
%             when matrices are large and not as critical on mem.
%             The more alike the eigenvalues are the better
%             the time-gain will be.
%
%  ftfixfom   Needed by the tuckerprograms for (re)arranging cubes.
%  
%  ftscale    Used for preprocessing the data.
%
% NEW PROGRAMS BEING DEVELOPED -------------------------------------
%
%  - The programs already in this collection will continuously be
%    refined and optimized and the new versions will be published 
%    as soon as they have been tested.
%  - Programs for doing cross-validation (CV) will be released during
%    late april.
%  - Soon, also four-, five- and higher-way procedures will be
%    published. In addition we also work with four-way TUCKER models.
%  
%
% Contact us:
%  If you have any comments, questions, suggestions or the like
%  don't hesitate to mail us here at Foodtechnology.
%  E-mail adresses : claus.andersson@pop.foodsci.kvl.dk  
%                    rasmus.bro@pop.foodsci.kvl.dk
%                    larsn@pop.foodsci.kvl.dk
